@@ -12,9 +12,18 @@ then
     exit;
 fi
 
+IMAGE_DIR="."
+
+if [ $# -eq 1 ]
+then
+    IMAGE_DIR=$1
+fi
+
 SIFT=$BASE_PATH/bin/sift
 
-for d in `ls -1 | egrep "jpg$"`
+for d in `ls -1 $IMAGE_DIR | egrep "jpg$"`
 do 
-    echo "mogrify -format pgm $d; $SIFT < `basename $d .jpg`.pgm > `basename $d .jpg`.key; rm `basename $d .jpg`.pgm; gzip `basename $d .jpg`.key"
+    pgm_file=$IMAGE_DIR/`echo $d | sed 's/jpg$/pgm/'`
+    key_file=$IMAGE_DIR/`echo $d | sed 's/jpg$/key/'`
+    echo "mogrify -format pgm $IMAGE_DIR/$d; $SIFT < $pgm_file > $key_file; rm $pgm_file; gzip $key_file"
 done
